package nl.kallestruik.dlib

import java.lang.reflect.Field

class ReflectionUtil {

    /**
     * Get a {@link Field} from the class provided.
     * @param clazz The class to get the field from.
     * @param fieldName The name of the field to get.
     */
    @Throws(NoSuchFieldException::class)
    fun getField(clazz: Class<*>, fieldName: String): Field {
        return try {
            clazz.getDeclaredField(fieldName)
        } catch (e: NoSuchFieldException) {
            val superClass = clazz.superclass
            superClass?.let { getField(it, fieldName) } ?: throw e
        }
    }

    /**
     * Get the value from a field on an object.
     * @param instance The instance of the object to take the value from.
     * @param fieldName The name of the field to take the value from.
     */
    fun getValueFromField(instance: Any, fieldName: String): Any? {
        try {
            val field = getField(instance.javaClass, fieldName)
            field.isAccessible = true //required if field is not normally accessible
            return field.get(instance)
        } catch (e: NoSuchFieldException) {
            e.printStackTrace()
        }
        return null
    }
}